class Alimento < ApplicationRecord
	has_many :ingredientes, :dependent => :destroy
	has_many :recetas, :through => :ingredientes

	 accepts_nested_attributes_for :ingredientes, allow_destroy: true

	#Humanized attributes for showing in a table
	HUMAN_ATTRIBUTE_NAMES = {
		:energia => "Energía",
		:proteina => "Proteína",
		:prot_animal => "Proteína animal",
		:prot_vegetal => "Proteína vegetal",
		:lipidos => "Grasas",
		:ags => "Ácidos Grasos Saturados",
		:agm => "Ácidos Grasos Monoinsaturados",
		:agp => "Ácidos Grasos Polisaturados",
		:glucidos => "Hidratos de carbono",
		:azucares => "Azúcares",
		:polisacaridos => "Polisácaridos", 
		:vit_d => "Vitamina D",
		:vit_e => "Vitamina E",
		:vit_b6 => "Vitamina B6",
		:acido_folico => "Ácido Fólico",
		:vit_b12 => "Vitamina B12",
		:vit_c => "Vitamina C",
		:vit_a => "Vitamina A",
		:etanol => "Alcohol (Etanol)",
		:na => "Sodio (Na)",
		:k => "Potasio (k)",
		:ca => "Calcio (Ca)",
		:mg => "Magnesio (Mg)",
		:p => "Fósforo (P)",
		:fe => "Hierro (Fe)",
		:zn => "Zinc (Zn)",


	}
	def fuente_rico_fibra
		#We calculate how much fiber this aliment have in 100Kcal
		fibra_por_100kcal = (fibra/energia)*100
		#If fibra is between 6 and 3 or fibra_por_100kcal is between 3 and 1,5 grams this aliment is fiber source
		if fibra > 6 || fibra == 6 || fibra_por_100kcal > 3 || fibra_por_100kcal == 3
			return "Rico en fibra"
		#If fibra is higher or equal to 6 or fibra_por_100kcal is higher or equal to 3 grams this aliment is fiber rich
		elsif (6 > fibra && (fibra > 3 || fibra == 3)) || 
						(3 > fibra_por_100kcal && (fibra_por_100kcal > 1.5 || fibra_por_100kcal == 1.5)) 
			return "Fuente de fibra"
		end
							
	end


	#If this aliment have between 12 and 20 % of total kcal is fiber rich, and if is higher than 20% is high protein content
	def fuente_alto_contenido_proteinas
		porcentaje = porcentaje_proteinas
		if porcentaje > 20 || porcentaje == 20
			return "Alto contenido en proteínas"
		elsif 20 > porcentaje && (porcentaje > 12 || porcentaje == 12)
			return "Fuente de proteínas"
		end

	end

	#Aliments with 15% of daily intake of any mineral or vitamin per 100 grams of that product, are consider source of that mineral or vitamin
	#Aliments consider as rich in that mineral or vitamin, are those who contain 30% of daily intake per 100 grams of product

	# Daily intake (in Spanish CDR) of calcium is 800mg
	def fuente_alto_contenido_calcio
		source = 800*0.15
		rich = 800*0.3
		if ca > rich || ca == rich 
			return "Rico en calcio"
		elsif ca < rich && (ca > source || ca == source)
			return "Fuente de calcio"
		end
	end

	# Daily intake (in Spanish CDR) of iron is 14mg
	def fuente_alto_contenido_hierro
		source = 14*0.15
		rich = 14*0.3
		if fe > rich || fe == rich 
			return "Rico en hierro"
		elsif fe < rich && (fe > source || fe == source)
			return "Fuente de hierro"
		end
	end

	# Daily intake (in Spanish CDR) of vitamin C is 80mg
	def fuente_alto_contenido_vit_c
		source = 80*0.15
		rich = 80*0.3
		if vit_c > rich || vit_c == rich 
			return "Rico en Vitamina C"
		elsif vit_c < rich && (vit_c > source || vit_c == source)
			return "Fuente de Vitamina C"
		end
	end

	# Daily intake (in Spanish CDR) of folic acid is 200ug
	def fuente_alto_contenido_acido_folico
		source = 200*0.15
		rich = 200*0.3
		if acido_folico > rich || acido_folico == rich 
			return "Rico en Ácido Fólico"
		elsif acido_folico < rich && (acido_folico > source || acido_folico == source)
			return "Fuente de Ácido Fólico"
		end
	end

	# Daily intake (in Spanish CDR) of phosphorus is 700mg
	def fuente_alto_contenido_fosforo
		source = 700*0.15
		rich = 700*0.3
		if p > rich || p == rich 
			return "Rico en Fósforo"
		elsif p < rich && (p > source || p == source)
			return "Fuente de Fósforo"
		end
	end

	# Daily intake (in Spanish CDR) of magnesium is 375mg
	def fuente_alto_contenido_magnesio
		source = 375*0.15
		rich = 375*0.3
		if mg > rich || mg == rich 
			return "Rico en Magnesio"
		elsif mg < rich && (mg > source || mg == source)
			return "Fuente de Magnesio"
		end
	end

	# Daily intake (in Spanish CDR) of zinc is 10mg
	def fuente_alto_contenido_zinc
		source = 10*0.15
		rich = 10*0.3
		if zn > rich || zn == rich 
			return "Rico en Zinc"
		elsif zn < rich && (zn > source || zn == source)
			return "Fuente de Zinc"
		end
	end

	#Methods for the show page, to make a table with this values
	def hidratos_kcal
		glucidos*4
	end

	def grasas_kcal
		lipidos*9
	end

	def proteinas_kcal
		proteina*4
	end 

	# Percentage of grams that represents each group of nutrients
	def porcentaje_hidratos
	  return (glucidos/(glucidos+lipidos+proteina))*100
	end

	def porcentaje_proteinas
	  return (proteina/(glucidos+lipidos+proteina))*100
	end

	def porcentaje_grasas
	  return (lipidos/(glucidos+lipidos+proteina))*100
	end

	# Methods for kcal percentages of the three type of nutrients
	def porcentaje_kcal_hidratos
	  return (glucidos*4/(glucidos*4+lipidos*9+proteina*4))*100
	end

	def porcentaje_kcal_proteinas
	  return (proteina*4/(glucidos*4+lipidos*9+proteina*4))*100
	end

	def porcentaje_kcal_grasas
	  return (lipidos*9/(glucidos*4+lipidos*9+proteina*4))*100
	end
	# This method change the name of attributes for displaying
	# on the page show.html.erb

	class << self
	    def human_attribute_name attribute_name
	      HUMAN_ATTRIBUTE_NAMES[attribute_name.to_sym] || super
	    end
	end
end
